@@ -50,15 +50,19 @@ DEFINITION = {
     ],
     'application_django': [
         ('django.core.handlers.wsgi', 'instrument'),
+        ('django.core.handlers.asgi', 'instrument_asgi'),
+        
         ('django.core.handlers.base', 'instrument_handlers_base'),
         ('django.views.generic.base', 'instrument_generic_base'),
         ('django.contrib.staticfiles.handlers', 'instrument_handlers_static'),
+        ('channels.http', 'instrument_handlers_channels'),
 
         # Django==1.10
         ('django.urls.resolvers', 'instrument_url_resolvers', False),
         ('django.urls.base', 'instrument_urls_base', False),
         ('django.core.handlers.exception', 'instrument_handlers_exception',
          False),
+
     ],
     'application_flask': [
         ('flask', 'instrument'),
